@@ -118,11 +118,12 @@ struct Language language[LANGUAGES]=
   { "roff", "\\\"", "" },
   { "SGML", "<!--", "-->" },
   { "Occam", "--", "" },
-  { "TeX", "%", "" },
-  { "Lisp", ";", "" },
   { "C++", "//", "" },
+  { "TeX", "%", "" },
+  { "Texinfo", "@c ", "" },
+  { "Lisp", ";", "" },
   { "Pascal", "(*", "*)" },
-  { "None", "", "" },
+  { "", "", "" },
   { (const char*)0, (const char*)0, (const char*)0 },
 };
 /*}}}*/
@@ -325,7 +326,6 @@ struct Language *bf_lang(struct Buffer *b, struct Language *l)
   return b->lang;
 }
 /*}}}*/
-
 /* bf_load       -- load buffer from file *//*{{{*/
 int bf_load(struct Buffer *b, const char *cmd, const char *file, int filefd, const char *beg, const char *end)
 {
@@ -354,11 +354,7 @@ int bf_load(struct Buffer *b, const char *cmd, const char *file, int filefd, con
   if (cmd) /*{{{*/
   {
     pipe(fd);
-#ifdef HAS_VFORK
-    switch (pid=vfork())
-#else
     switch (pid=fork())
-#endif
     {
       case 0:
       {
@@ -384,7 +380,7 @@ int bf_load(struct Buffer *b, const char *cmd, const char *file, int filefd, con
   /*}}}*/
   else /*{{{*/
   {
-    struct stat buf;
+    struct stat statbuf;
 
     if (file)
     {
@@ -392,8 +388,8 @@ int bf_load(struct Buffer *b, const char *cmd, const char *file, int filefd, con
       if (access(file,W_OK)==-1 && errno==EACCES) readonly=1;
     }
     else { file="(stdin)"; fd[0]=filefd; }
-    if (fstat(fd[0],&buf)==-1) return 0;
-    if (S_ISDIR(buf.st_mode)) { errno=EISDIR; return 0; }
+    if (fstat(fd[0],&statbuf)==-1) return 0;
+    if (S_ISDIR(statbuf.st_mode)) { errno=EISDIR; return 0; }
   }
   /*}}}*/
   eof=0;
@@ -403,34 +399,32 @@ int bf_load(struct Buffer *b, const char *cmd, const char *file, int filefd, con
     if (linerun==line+linesize)
     {
       if ((line=realloc(line,linesize+256))==(char*)0)
-    /* can not allocate more memory, close file and return failure *//*{{{*/
-    {
-      int oerrno;
+      /* can not allocate more memory, close file and return failure *//*{{{*/
+      {
+        int oerrno;
 
-      oerrno=errno;
-      free(line);
-      close(fd[0]);
-      if (cmd) while (wait(&status)!=pid);
-      errno=oerrno;
-      return 0;
-    }
-    /*}}}*/
-    else
-    {
-      linerun=line+linesize;
-      linesize+=256;
-    }    
+        oerrno=errno;
+        free(line);
+        close(fd[0]);
+        if (cmd) while (wait(&status)!=pid);
+        errno=oerrno;
+        return 0;
+      }
+      /*}}}*/
+      else
+      {
+        linerun=line+linesize;
+        linesize+=256;
+      }    
     }
     /*}}}*/
     /* read new block if needed *//*{{{*/
     if (remaining==0 && (remaining=read(fd[0],bufrun=buf,sizeof(buf)))<=0) eof=1;
     /*}}}*/
     --remaining;
-    if ((eof || (*linerun++=*bufrun++)=='\n') && linerun>line)
-    /* process line *//*{{{*/
+    if ((eof || (*linerun++=*bufrun++)=='\n') && linerun>line) /* process line */
     {
-      if (search_for==LANGUAGE)
-      /* search for magic mark *//*{{{*/
+      if (search_for==LANGUAGE) /* search for magic mark *//*{{{*/
       {
         const char *found_beg,*found_end;
 
@@ -438,56 +432,50 @@ int bf_load(struct Buffer *b, const char *cmd, const char *file, int filefd, con
         {
           struct Language *langrun;
 
-          /* search for given language *//*{{{*/
-          for (langrun=language; langrun->name!=(const char*)0 && strncmp(found_beg+begsz,langrun->name,strlen(langrun->name)); ++langrun);
-          /*}}}*/
-          if (langrun->name==(const char*)0)
-          /* not found, so this was just a regular line *//*{{{*/
+          /* search for given language between begin/end */ /*{{{*/
+          for (langrun=language; langrun->name!=(const char*)0; ++langrun)
+          {
+            if (strncmp(found_beg+begsz,langrun->name,strlen(langrun->name))==0)
+            {
+              /* variables */ /*{{{*/
+              const char *found;
+              /*}}}*/
+
+              /* determine opening and closing fold marks */ /*{{{*/
+              if (opening) free(opening);
+              if (closing) free(closing);
+              opening=malloc((openingsz=strlen(langrun->beg)+begsz+strlen(langrun->end))+1);
+              strcpy(opening,langrun->beg);
+              strcpy(opening+strlen(langrun->beg),beg);
+              strncpy(opening+strlen(langrun->beg)+begsz,langrun->end,strlen(langrun->end));
+              closing=malloc((closingsz=strlen(langrun->beg)+endsz+strlen(langrun->end))+1);
+              strcpy(closing,langrun->beg);
+              strcpy(closing+strlen(langrun->beg),end);
+              strncpy(closing+strlen(langrun->beg)+endsz,langrun->end,strlen(langrun->end));
+              /*}}}*/
+              /* now check if this is also a opening fold */
+              if ((found=mymemmem(found_end+endsz,linerun-found_end-endsz,opening,openingsz))!=(char*)0) /* good */ /*{{{*/
+              {
+                const char *s;
+
+                for (s=line; s<found_beg-strlen(langrun->beg); ++s) bf_insert(b,*s,NUL);
+                for (s=found_end+endsz+strlen(langrun->end); s<found; ++s) bf_insert(b,*s,NUL);
+                bf_insert(b,'\0',FOLDSTART);
+                for (s=found+openingsz; s<linerun; ++s) bf_insert(b,*s,NUL);
+                search_for=FOLDS;
+                b->lang=langrun;
+                break;
+              }
+              /*}}}*/
+            }
+          }
+          if (langrun->name==(const char*)0) /* not found, so this was just a regular line */ /*{{{*/
           {
             char *s;
 
             for (s=line; s<linerun; ++s) bf_insert(b,*s,NUL);
           }
           /*}}}*/
-          else
-          /* found, now check if this is also a starting fold *//*{{{*/
-          {
-            /* variables *//*{{{*/
-            const char *found;
-            /*}}}*/
-
-            /* determine opening and closing fold marks *//*{{{*/
-            opening=malloc(openingsz=strlen(langrun->beg)+begsz+strlen(langrun->end));
-            strcpy(opening,langrun->beg);
-            strcpy(opening+strlen(langrun->beg),beg);
-            strncpy(opening+strlen(langrun->beg)+begsz,langrun->end,strlen(langrun->end));
-            closing=malloc(closingsz=strlen(langrun->beg)+endsz+strlen(langrun->end));
-            strcpy(closing,langrun->beg);
-            strcpy(closing+strlen(langrun->beg),end);
-            strncpy(closing+strlen(langrun->beg)+endsz,langrun->end,strlen(langrun->end));
-            /*}}}*/
-            if ((found=mymemmem(found_end+endsz,linerun-found_end-endsz,opening,openingsz))!=(char*)0)
-            /* good, this line is also an opening fold *//*{{{*/
-            {
-              const char *s;
-
-              for (s=line; s<found_beg-strlen(langrun->beg); ++s) bf_insert(b,*s,NUL);
-              for (s=found_end+endsz+strlen(langrun->end); s<found; ++s) bf_insert(b,*s,NUL);
-              bf_insert(b,'\0',FOLDSTART);
-              for (s=found+openingsz; s<linerun; ++s) bf_insert(b,*s,NUL);
-              search_for=FOLDS;
-              b->lang=langrun;
-            }
-            /*}}}*/
-            else 
-            /* let's forget about it, this was just a regular line *//*{{{*/
-            {
-              const char *s;
-
-              for (s=line; s<linerun; ++s) bf_insert(b,*s,NUL);
-            }
-            /*}}}*/
-          }
           /*}}}*/
         }
         else
@@ -498,8 +486,7 @@ int bf_load(struct Buffer *b, const char *cmd, const char *file, int filefd, con
         }
       }
       /*}}}*/
-      else
-      /* search for folds *//*{{{*/
+      else /* search for folds *//*{{{*/
       {
         const char *found,*s;
         
@@ -523,7 +510,6 @@ int bf_load(struct Buffer *b, const char *cmd, const char *file, int filefd, con
       /*}}}*/
       linerun=line;
     }
-    /*}}}*/
   } while (!eof);
   close(fd[0]);
   if (cmd) while (wait(&status)!=pid);
@@ -914,14 +900,14 @@ int bf_regfsearch(struct Buffer *b, const regex_t *needle)
 /* bf_strbsearch -- goto line of backwards searched string *//*{{{*/
 int bf_strbsearch(struct Buffer *b, const char *needle, size_t needlesize)
 {
-  char *found;
+  int back=0;
 
-  if (b->gapstart>(b->buffer+1) && (found=myrmemmem(b->buffer,b->gapstart-b->buffer-1,needle,needlesize)))
+  while (memcmp(b->gapend+1,needle,needlesize))
   {
-    while (b->gapstart>found && BF_BACKWARDOK(b)) BF_BACKWARD(b);
-    return 1;
+    if (BF_BACKWARDOK(b)) { ++back; BF_BACKWARD(b); }
+    else { while (back>0) { --back; BF_FORWARD(b); } return 0; }
   }
-  else return 0;
+  return 1;
 }
 /*}}}*/
 /* bf_regbsearch -- goto line of backwards searched string *//*{{{*/
