@@ -23,10 +23,10 @@
 .ds k \fP
 .\"}}}
 .\"{{{ Title
-.ND "January 7th, 1998"
+.ND "February 10th, 2004"
 .TL
 Fe User Guide
-.AU "Michael Haardt (michael@cantor.informatik.rwth-aachen.de)"
+.AU "Michael Haardt <michael@moria.de>"
 .AF ""
 .AS "" 0.5i
 Yet another editor? Yes, and like all other editors, its special
@@ -45,29 +45,23 @@ in particular to the Emacs-like interface of Origami.
 .MT 4 1
 .\"}}}
 .H 1 "Copyright and usage conditions" \"{{{
-\*Cfe\*c (Folding editor) is copyright (c) by Michael Haardt, 1995\(en1998.  You
-may use and modify this program or derived works without charge for
-personal use and at work under the condition that no copyright notices
-are removed or changed.  Distributing fe under different conditions and
-any commercial use like charging for copying or selling it or derived
-works, alone or as part of a bigger product, needs a written license
-from me.
+\*Cfe\*c (Folding editor) is copyright (c) by Michael Haardt <michael@moria.de>, 1995\(en2004.
 .P
-I can be reached by:
-.DS I
-Snail mail:
-Michael Haardt
-Fuhrweg 33
-53229 Bonn
-Germany
-
-Email:
-michael@cantor.informatik.rwth-aachen.de
-.DE
-Disclaimer: I am in no way responsible for anything caused by using this
-program, so if your computer or house blows up, that's your problem.  :)
+This program is free software; you can redistribute it and/or modify
+it under the terms of the GNU General Public License as published by
+the Free Software Foundation; either version 2 of the License, or
+(at your option) any later version.
 .P
-Fe is available at \*Aftp://cantor.informatik.rwth-aachen.de/pub/unix/fe.tar.gz\*a.
+This program is distributed in the hope that it will be useful,
+but WITHOUT ANY WARRANTY; without even the implied warranty of
+MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+GNU General Public License for more details.
+.P
+You should have received a copy of the GNU General Public License along
+with this program.  If not, write to the Free Software Foundation, Inc.,
+59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+.P
+The source is available from \*Ahttp://www.moria.de/~michael/fe/\*a.
 .\"}}}
 .H 1 "First things first" \"{{{
 The first thing you will notice in fe is the status line, which tells you
@@ -114,7 +108,7 @@ Strings to search for or replace
 The command line editor further does file name completion with the
 \*Ktab\*k key (\*KC-i\*k).
 .P
-Although it is commonly said that you edit a file, what you really do
+Although it is commonly said that you edit a file, what you really doing
 is loading the file into a buffer in memory, edit this buffer and later
 write it back into a file.  As such, if you do not save the buffer, all
 your work, no matter how much, is lost.  It is advised to save regularly,
@@ -127,7 +121,7 @@ If you are a new user, then read below for the most important commands:
 This brings you into the main menu.  Using the menu is slower than
 directly typing the commands you want to use, but if you are a new
 user, it may help you until you know all commands.  You can leave any
-meny with \*KC-g\*k.
+menu with \*KC-g\*k.
 .\"}}}
 .\"{{{ M-z                  -- save and exit
 .Li \*KM-z\*k
