@@ -1,7 +1,12 @@
 #ifndef MACRO_H
 #define MACRO_H
 
+#include <stdarg.h> /* required by some curses.h implementations */
+#ifdef NEED_NCURSES
+#include <ncurses.h>
+#else
 #include <curses.h>
+#endif
 
 struct Macro
 {
